.. _data:

Working with Data
=================

Introduction to the key parts of LinkML that you need to know:

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   working-with-data
   validating-data
   rdf
   json
   csvs
   python

